Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS Support.

Actions, resources, and condition keys for AWS Support - Service Authorization Reference

# Actions, resources, and condition keys for AWS Support

AWS Support (service prefix: `support` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions defined by AWS Support
- Resource types defined by AWS Support
- Condition keys for AWS Support

## Actions defined by AWS Support

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see Actions table .

Note

AWS Support provides the ability to access, modify and resolve cases, as well as use Trusted Advisor actions. When you use the Support API to call Trusted Advisor-related actions, none of the "trustedadvisor:*" actions restrict your access. The "trustedadvisor:*" actions apply only to Trusted Advisor in the AWS Management Console.

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
AddAttachmentsToSet | Adds one or more attachments to an AWS Support case. | Write |  |  |
AddCommunicationToCase | Adds a customer communication to an AWS Support case. | Write |  |  |
CreateCase | Creates a new AWS Support case. | Write |  |  |
DescribeAttachment | Returns the description for an attachment. | Read |  |  |
DescribeCaseAttributes | This is an internally managed function which allows secondary services to read AWS Support case attributes. | Read |  |  |
DescribeCases | Returns a list of AWS Support cases that matches the given inputs. | Read |  |  |
DescribeCommunications | Returns the communications and attachments for one or more AWS Support cases. | Read |  |  |
DescribeIssueTypes | Returns issue types for AWS Support cases. | Read |  |  |
DescribeServices | Returns the current list of AWS services and categories that applies to each service. | Read |  |  |
DescribeSeverityLevels | Returns the list of severity levels that can be assigned to an AWS Support case. | Read |  |  |
DescribeSupportLevel | Returns the support level for an AWS Account identifier. | Read |  |  |
DescribeTrustedAdvisorCheckRefreshStatuses | Returns the status of a Trusted Advisor refresh check based on a list of check identifiers. | Read |  |  |
DescribeTrustedAdvisorCheckResult | Returns the results of the Trusted Advisor check that has the specified check identifier. | Read |  |  |
DescribeTrustedAdvisorCheckSummaries | Returns the summaries of the results of the Trusted Advisor checks that have the specified check identifiers. | Read |  |  |
DescribeTrustedAdvisorChecks | Returns a list of all available Trusted Advisor checks, including name, identifier, category and description. | Read |  |  |
InitiateCallForCase | This is an internally managed function to initiate a call on AWS Support Center. | Write |  |  |
InitiateChatForCase | This is an internally managed function to initiate a chat on AWS Support Center. | Write |  |  |
PutCaseAttributes | This is an internally managed function which allows secondary services to attach attributes to AWS Support cases. | Write |  |  |
RateCaseCommunication | Rate an AWS Support case communication. | Write |  |  |
RefreshTrustedAdvisorCheck | Requests a refresh of the Trusted Advisor check that has the specified check identifier. | Write |  |  |
ResolveCase | Resolves an AWS Support case. | Write |  |  |
SearchForCases | Returns a list of AWS Support cases that matches the given inputs. | Read |  |  |

## Resource types defined by AWS Support

AWS Support does not support specifying a resource ARN in the `Resource` element of an IAM policy statement. To allow access to AWS Support, specify `“Resource”: “*”` in your policy.

## Condition keys for AWS Support

Support has no service-specific context keys that can be used in the `Condition` element of policy statements. For the list of the global context keys that are available to all services, see Available keys for conditions .

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.